@@ -11,6 +11,7 @@ import traceback
 from collections import namedtuple
 from contextlib import contextmanager
 from dataclasses import dataclass
+from pathlib import Path
 from typing import ContextManager, Dict, Optional
 
 from duckietown_challenges import ChallengesConstants
@@ -272,7 +273,7 @@ class ChallengeInterfaceEvaluatorConcrete(ChallengeInterfaceEvaluator):
     ipfs_hashes: Dict[str, str]
 
     def __init__(self, root=DEFAULT_ROOT):
-        dclogger.info(f"ChallengeInterfaceEvaluatorConcrete root = {root}")
+
         self.root = root
 
         self.challenge_files = FS()  # -> ChallengeFile
@@ -282,6 +283,15 @@ class ChallengeInterfaceEvaluatorConcrete(ChallengeInterfaceEvaluator):
         self.ipfs_hashes = {}
         self.scores = {}  # str -> ReportedScore
 
+    def internal_checks(self):
+        root = self.root
+        path = Path(root)
+        files = list(map(str, path.rglob("*.*")))
+        dclogger.info(f"ChallengeInterfaceEvaluatorConcrete", root=root, files=files)
+        if not files:
+            msg = "Invalid environment: challenges directory is empty. Not mounted correctly?"
+            raise InvalidEnvironment(msg=msg, root=root, files=files)
+
     def set_challenge_parameters(self, data):
         assert isinstance(data, dict)
         self.parameters = data
@@ -653,8 +663,6 @@ def scoring_context(root=DEFAULT_ROOT) -> ContextManager[ChallengeInterfaceEvalu
         dclogger.info(f"exiting with code {retcode}")
         sys.exit(retcode)
 
-    cie = ChallengeInterfaceEvaluatorConcrete(root=root)
-
     # NOTE you have to call after yielding
     def read_scores():
         _scores = {}
@@ -662,7 +670,11 @@ def scoring_context(root=DEFAULT_ROOT) -> ContextManager[ChallengeInterfaceEvalu
             _scores[k] = v.value
         return _scores
 
+    cie = ChallengeInterfaceEvaluatorConcrete(root=root)
+
     try:
+        cie.internal_checks()
+
         yield cie
         status = ChallengesConstants.STATUS_JOB_SUCCESS
         dclogger.debug("yield cie ok, now declaring success", status=status, scores=read_scores())
@@ -684,8 +696,10 @@ def scoring_context(root=DEFAULT_ROOT) -> ContextManager[ChallengeInterfaceEvalu
         status = ChallengesConstants.STATUS_JOB_HOST_ERROR
         declare(status, msg, read_scores(), cie.ipfs_hashes)
 
-    except SystemExit:
-        # msg = "SystemExit:\n%s" % traceback.format_exc()
+    except SystemExit as e:
+        if e.code:
+            msg = "SystemExit:\n%s" % traceback.format_exc()
+            dclogger.error(msg)
         # declare(
         #     ChallengesConstants.STATUS_JOB_FAILED, msg, read_scores(), cie.ipfs_hashes
         # )
@@ -693,8 +707,14 @@ def scoring_context(root=DEFAULT_ROOT) -> ContextManager[ChallengeInterfaceEvalu
 
     except BaseException:
         msg = "Unexpected exception:\n%s" % traceback.format_exc()
+        dclogger.error(msg)
         declare(ChallengesConstants.STATUS_JOB_ERROR, msg, read_scores(), cie.ipfs_hashes)
 
+    finally:
+        cmd = "sync"
+        subprocess.check_call(cmd)
+    cie.info("Graceful termination of scoring_context().")
+
 
 def wrap_solution(solution, root=DEFAULT_ROOT):
     from .col_logging import setup_logging_color
