@@ -1,6 +1,8 @@
 # coding=utf-8
 import os
 
+from typing import List
+
 DEFAULT_ROOT = "/challenges"
 
 # In the end, the evaluator must create this file
@@ -48,6 +50,7 @@ ENV_CHALLENGE_STEP_NAME = "challenge_step_name"
 #     # XXX: to merge
 
 
+DTSERVER_ENV = "DTSERVER"
 DEFAULT_DTSERVER = "https://challenges.duckietown.org/v4"
 
 
@@ -56,10 +59,8 @@ class Storage(object):
 
 
 def get_duckietown_server_url():
-    V = "DTSERVER"
-
-    if V in os.environ:
-        use = os.environ[V]
+    if DTSERVER_ENV in os.environ:
+        use = os.environ[DTSERVER_ENV]
         if not Storage.done:
             if use != DEFAULT_DTSERVER:
                 msg = "Using server %s instead of default %s" % (use, DEFAULT_DTSERVER)
@@ -70,3 +71,19 @@ def get_duckietown_server_url():
         return use
     else:
         return DEFAULT_DTSERVER
+
+
+IMPORTANT_ENVS = {
+    "AIDO_REGISTRY": "docker.io",
+    "PIP_INDEX_URL": "https://pypi.org/simple",
+    DTSERVER_ENV: DEFAULT_DTSERVER,
+}
+
+
+def get_important_env_build_args(dockerfile_content: str) -> List[str]:
+    args = []
+    for vname, default_value in IMPORTANT_ENVS.items():
+        if vname in dockerfile_content:
+            value = os.environ.get(vname, default_value)
+            args.extend(["--build-arg", f"{vname}={value}"])
+    return args
