@@ -5,6 +5,7 @@ import dateutil.parser
 import termcolor
 from zuper_commons.timing import now_utc
 
+
 from .challenge import ChallengeDescription
 from .challenges_constants import ChallengesConstants
 from .rest import make_server_request
@@ -14,6 +15,7 @@ Endpoints = ChallengesConstants.Endpoints
 
 SubmissionID = NewType("SubmissionID", int)
 UserID = NewType("UserID", int)
+JobID = NewType("JobID", int)
 
 
 @dataclass
@@ -260,6 +262,31 @@ def dtserver_work_submission(
     )
 
 
+def dtserver_job_heartbeat(
+    token: str,
+    job_id: JobID,
+    machine_id,
+    process_id,
+    evaluator_version,
+    impersonate: Optional[UserID] = None,
+):
+
+    endpoint = Endpoints.job_heartbeat
+    method = "GET"
+    data = {
+        "job_id": job_id,
+        "machine_id": machine_id,
+        "process_id": process_id,
+        "evaluator_version": evaluator_version,
+    }
+    add_version_info(data)
+    add_impersonate_info(data, impersonate)
+    timeout = 10
+    return make_server_request(
+        token, endpoint, data=data, method=method, timeout=timeout, suppress_user_msg=True,
+    )
+
+
 def get_challenge_description(
     token, challenge_name: str, impersonate: Optional[UserID] = None
 ) -> ChallengeDescription:
